abclinuxu.cz AbcLinuxu.cz itbiz.cz ITBiz.cz HDmag.cz HDmag.cz abcprace.cz AbcPráce.cz
AbcLinuxu hledá autory!
Inzerujte na AbcPráce.cz od 950 Kč
Rozšířené hledání
×

    dnes 13:44 | IT novinky

    Největší kryptoměnová burza světa Binance se stala terčem útoku, při kterém podvodníci odcizili během několika minut kryptoměny v hodnotě přibližně 6,3 miliardy dolarů. Jedná se o největší kryptoměnovou krádež v historii, přibližně čtyřikrát větší než loňský útok na burzu Bybit. Binance se podařilo ve spolupráci s partnery zmrazit aspoň aktiva v hodnotě zhruba 3 miliard dolarů a slíbila, že veškeré ztráty pokryje z vlastních prostředků.

    Ladislav Hagara | Komentářů: 6
    dnes 02:16 | Bezpečnostní upozornění

    Zranitelnost CVE-2026-98432 s CVSS 9.8 odhalila AI od společnosti Anthropic. Jedná se o kritickou chybu v implementaci MPTCP (multipath TCP). Debian vydal patche 16.10. a 22.10., ale např. Ubuntu je zatím bez opravy. Více informací na The Hacker News.

    Max | Komentářů: 16
    včera 23:22 | Zajímavý software

    Na Slovensku vznikla úplne nová rally hra, ktorá je zadarmo a funguje vo Windowse, Linuxe či na Macu. Greenie Rally má viac ako 50 tratí a vozidiel, šampionáty či turnaje. Má retro feeling a imituje automobilové hry z prelomu tisícročí. Vyskúšate prejsť všetky mapy na Škode 130RS?

    Stanislav Hoferek | Komentářů: 4
    včera 14:33 | Komunita

    Do základního systému NetBSD -current byl přidán nový editor atto jako alternativa k editorům vi a xedit.

    Ladislav Hagara | Komentářů: 1
    včera 14:11 | IT novinky

    Společnost System76 představila kompaktní 11litrový Thelio Prime Desktop. S procesorem AMD Ryzen 9000. S Pop!_OS 24.04 LTS s desktopovým prostředím COSMIC nebo Ubuntu 24.04 LTS.

    Ladislav Hagara | Komentářů: 0
    včera 13:44 | Humor

    Čínská státní televize pozastavila vysílání španělské La Ligy a čínské internetové platformy omezily obsah s Kylianem Mbappém poté, co slavný fotbalista ve francouzském pořadu The Bridge mluvil o svém oblíbeném memu, v němž je jeho tvář vložena do portrétu zobrazujícího diktátora Mao Ce-tunga. 'Můj oblíbený mem je ten, na kterém dali můj obličej na čínského diktátora. To mě opravdu rozesmívá. S přáteli ho používám pořád' řekl,

    … více »
    Pendrekama do nich❗ | Komentářů: 7
    včera 13:22 | IT novinky

    Při příležitosti oslav Dne vzniku samostatného československého státu (28. října) byly uděleny medaile Za zásluhy tvůrci aplikace Záchranka Filipu Maleňákovi, vědci v oblasti umělé inteligence Tomáši Mikolovovi a Olze Štěpánkové, vědkyni zabývající se kybernetikou, robotikou a strojovým učením, průkopnici v oblastech výuky a využití umělé inteligence v medicínském inženýrství.

    Pendrekama do nich❗ | Komentářů: 7
    včera 01:33 | IT novinky

    Apple představil nový iPad mini, iMac s čipem M6, 14palcový MacBook Pro s čipem M6 a MacBook Pro s PROLED XDR displejem – první Mac s dotykovým ovládáním.

    Ladislav Hagara | Komentářů: 5
    28.10. 23:22 | Zajímavý projekt

    Nedávno představený projekt mapSTL.com řeší budoucnost. 𝕏: "Netušil jsem, kolik patentů na generování map existuje. Existují patenty na generování fantasy map 🫣. Cokoliv je na 3D tiskárnu a tvoří to produkt, bude to mít patenty. Tak bacha na to!" … více »

    Ladislav Hagara | Komentářů: 5
    28.10. 18:55 | Nová verze

    Multiplatformní emulátor terminálu Ghostty byl vydán ve verzi 1.4 (𝕏). Přehled novinek a vylepšení v poznámkách k vydání.

    Ladislav Hagara | Komentářů: 0
    Které desktopové prostředí na Linuxu používáte?
     (9%)
     (7%)
     (4%)
     (20%)
     (29%)
     (9%)
     (5%)
     (2%)
     (14%)
     (20%)
    Celkem 2946 hlasů
     Komentářů: 34, poslední 26.10. 08:24
    Rozcestník

    Dotaz: kaffeine -tv

    14.7.2023 00:49 Míra
    kaffeine -tv
    Přečteno: 711×
    Zdravím, na PC provozuju kaffeine TV a vše funguje. Jen musím spustit kaffeine a potom ručně spustit TV.
    Příkaz kaffeine -t spustí jen kaffeine bez TV a to pak musím zas spustit ručně. Znáte někdo možnost, jak spustit kaffeine rovnou do TV?
    Mám Kubuntu, ale v tom to asi nebude...
    Dík za nápovědu

    Odpovědi

    Max avatar 14.7.2023 08:31 Max | skóre: 73 | blog: Max_Devaine
    Rozbalit Rozbalit vše Re: kaffeine -tv
    Jednou z možností je parametr "--tv", který ještě vyžaduje další parametr, kterým je číslo kanálu. Je to ale nedoporučená volba. Spíše zkus toto:
    kaffeine --lastchannel
    
    Zdar Max
    Měl jsem sen ... :(
    Max avatar 14.7.2023 08:34 Max | skóre: 73 | blog: Max_Devaine
    Rozbalit Rozbalit vše Re: kaffeine -tv
    Jinak tedy já mám tento help:
    kaffeine --help
    Použití: kaffeine [volby] [file]
    Přehrávač multimédií KDE s podporou digitální TV.
    
    Volby:
      -d, --debug                    Enable all debug messages. Please notice that
                                     Kaffeine also allows enabling debug messages
                                     per category, by using the environment var:
                                     QT_LOGGING_RULES=kaffeine.category.debug=true
                                     where 'category' can be:
                                     cam, dev, dvb, dvbsi, epg, config, mediawidget,
                                     playlist, sql, vlc
      --tempfile                     Soubory/URL otevřené aplikací budou po použití
                                     smazány
      -f, --fullscreen               Spustit v celoobrazovkovém režimu
      -m, --minimal                  Spouštět v minimálním režimu
      -t, --alwaysontop              Spustit vždy navrchu
      --audiocd                      Přehrát audio CD
      --videocd                      Přehrát video CD
      --dvd                          Přehrát DVD
      --aspectratio <aspect ratio>   Force starting with an specific aspect ratio
      --dumpdvb                      Zahazovat dvb data (ladicí volba)
      --channel <name / number>      Přehrávat TV kanál
      --tv <channel>                 (nedoporučovaná volba)
      --lastchannel                  Přehrávat naposledy naladěný TV kanál
      -v, --version                  Zobrazit informace o verzi.
      -h, --help                     Displays help on commandline options.
      --help-all                     Displays help including Qt specific options.
      --author                       Zobrazit informaci o autorech.
      --license                      Zobrazit informaci o licenci.
      --desktopfile <název souboru>  Základní název souboru položky na ploše pro
                                     tuto aplikaci.
    
    Argumenty:
      [file]                         Soubory nebo URL pro přehrání
    
    Zdar Max
    Měl jsem sen ... :(
    17.7.2023 14:13 Míra
    Rozbalit Rozbalit vše Re: kaffeine -tv
    kaffeine --lastchannel, případně kaffeine --channel číslo, funguje;
    ale nějak divně, protože nelze přepínat mezi kanály.
    Což při ručním spuštění lze. Samotný příkaz kaffeine samozřejmě funguje, ale bohužel se nespustí v režimu TV.

    Založit nové vlákno • Nahoru

    Tiskni Sdílej: Linkuj Jaggni to Vybrali.sme.sk Google Del.icio.us Facebook

    ISSN 1214-1267   www.czech-server.cz
    © 1999-2015 Nitemedia s. r. o. Všechna práva vyhrazena.